@@ -392,7 +392,7 @@ class ConnectionTest extends TestCase
     }
 
     /** @return bool[][] */
-    public function resultProvider(): array
+    public static function resultProvider(): array
     {
         return [[true], [false]];
     }
@@ -739,6 +739,50 @@ class ConnectionTest extends TestCase
         self::assertSame($platformMock, $connection->getDatabasePlatform());
     }
 
+    public function testPlatformDetectionFetchedFromParameters(): void
+    {
+        $driverMock = $this->createMock(VersionAwarePlatformDriver::class);
+
+        $driverConnectionMock = $this->createMock(ServerInfoAwareConnection::class);
+
+        $platformMock = $this->createMock(AbstractPlatform::class);
+
+        $connection = new Connection(['serverVersion' => '8.0'], $driverMock);
+
+        $driverMock->expects(self::never())
+            ->method('connect')
+            ->willReturn($driverConnectionMock);
+
+        $driverMock->expects(self::once())
+            ->method('createDatabasePlatformForVersion')
+            ->with('8.0')
+            ->willReturn($platformMock);
+
+        self::assertSame($platformMock, $connection->getDatabasePlatform());
+    }
+
+    public function testPlatformDetectionFetchedFromPrimaryReplicaParameters(): void
+    {
+        $driverMock = $this->createMock(VersionAwarePlatformDriver::class);
+
+        $driverConnectionMock = $this->createMock(ServerInfoAwareConnection::class);
+
+        $platformMock = $this->createMock(AbstractPlatform::class);
+
+        $connection = new Connection(['primary' => ['serverVersion' => '8.0']], $driverMock);
+
+        $driverMock->expects(self::never())
+            ->method('connect')
+            ->willReturn($driverConnectionMock);
+
+        $driverMock->expects(self::once())
+            ->method('createDatabasePlatformForVersion')
+            ->with('8.0')
+            ->willReturn($platformMock);
+
+        self::assertSame($platformMock, $connection->getDatabasePlatform());
+    }
+
     public function testConnectionParamsArePassedToTheQueryCacheProfileInExecuteCacheQuery(): void
     {
         $cacheItemMock = $this->createMock(CacheItemInterface::class);
