@@ -4,9 +4,9 @@ namespace Doctrine\DBAL\Tests\Driver\PDO\MySQL;
 
 use Doctrine\DBAL\Driver as DriverInterface;
 use Doctrine\DBAL\Driver\PDO\MySQL\Driver;
-use Doctrine\DBAL\Tests\Driver\AbstractMySQLDriverTest;
+use Doctrine\DBAL\Tests\Driver\AbstractMySQLDriverTestCase;
 
-class DriverTest extends AbstractMySQLDriverTest
+class DriverTest extends AbstractMySQLDriverTestCase
 {
     protected function createDriver(): DriverInterface
     {
