@@ -4,9 +4,9 @@ namespace Doctrine\DBAL\Tests\Driver\PDO\OCI;
 
 use Doctrine\DBAL\Driver as DriverInterface;
 use Doctrine\DBAL\Driver\PDO\OCI\Driver;
-use Doctrine\DBAL\Tests\Driver\AbstractOracleDriverTest;
+use Doctrine\DBAL\Tests\Driver\AbstractOracleDriverTestCase;
 
-class DriverTest extends AbstractOracleDriverTest
+class DriverTest extends AbstractOracleDriverTestCase
 {
     protected function createDriver(): DriverInterface
     {
