@@ -4,9 +4,9 @@ namespace Doctrine\DBAL\Tests\Driver\PDO\SQLSrv;
 
 use Doctrine\DBAL\Driver as DriverInterface;
 use Doctrine\DBAL\Driver\PDO\SQLSrv\Driver;
-use Doctrine\DBAL\Tests\Driver\AbstractSQLServerDriverTest;
+use Doctrine\DBAL\Tests\Driver\AbstractSQLServerDriverTestCase;
 
-class DriverTest extends AbstractSQLServerDriverTest
+class DriverTest extends AbstractSQLServerDriverTestCase
 {
     protected function createDriver(): DriverInterface
     {
