@@ -4,11 +4,11 @@ namespace Doctrine\DBAL\Tests\Functional\Driver\SQLSrv;
 
 use Doctrine\DBAL\Driver as DriverInterface;
 use Doctrine\DBAL\Driver\SQLSrv\Driver;
-use Doctrine\DBAL\Tests\Functional\Driver\AbstractDriverTest;
+use Doctrine\DBAL\Tests\Functional\Driver\AbstractDriverTestCase;
 use Doctrine\DBAL\Tests\TestUtil;
 
 /** @requires extension sqlsrv */
-class DriverTest extends AbstractDriverTest
+class DriverTest extends AbstractDriverTestCase
 {
     protected function setUp(): void
     {
