@@ -5,6 +5,8 @@ namespace Doctrine\DBAL\Tests\Functional;
 use Doctrine\DBAL\FetchMode;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
+use Doctrine\DBAL\Types\Types;
+use Doctrine\Deprecations\PHPUnit\VerifyDeprecations;
 use LogicException;
 
 use function array_change_key_case;
@@ -14,11 +16,13 @@ use const CASE_LOWER;
 
 class LegacyAPITest extends FunctionalTestCase
 {
+    use VerifyDeprecations;
+
     protected function setUp(): void
     {
         $table = new Table('legacy_table');
-        $table->addColumn('test_int', 'integer');
-        $table->addColumn('test_string', 'string');
+        $table->addColumn('test_int', Types::INTEGER);
+        $table->addColumn('test_string', Types::STRING);
         $table->setPrimaryKey(['test_int']);
 
         $this->dropAndCreateTable($table);
@@ -39,7 +43,10 @@ class LegacyAPITest extends FunctionalTestCase
         $sql = 'SELECT test_int FROM legacy_table WHERE test_int = 1';
 
         $stmt = $this->connection->executeQuery($sql);
-        $row  = array_change_key_case($stmt->fetch(FetchMode::ASSOCIATIVE), CASE_LOWER);
+
+        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/4007');
+
+        $row = array_change_key_case($stmt->fetch(FetchMode::ASSOCIATIVE), CASE_LOWER);
         self::assertEquals(1, $row['test_int']);
     }
 
@@ -48,7 +55,10 @@ class LegacyAPITest extends FunctionalTestCase
         $sql = 'SELECT test_int FROM legacy_table WHERE test_int = 1';
 
         $stmt = $this->connection->executeQuery($sql);
-        $row  = $stmt->fetch(FetchMode::NUMERIC);
+
+        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/4007');
+
+        $row = $stmt->fetch(FetchMode::NUMERIC);
         self::assertEquals(1, $row[0]);
     }
 
@@ -57,7 +67,10 @@ class LegacyAPITest extends FunctionalTestCase
         $sql = 'SELECT test_int FROM legacy_table WHERE test_int = 1';
 
         $stmt = $this->connection->executeQuery($sql);
-        $row  = $stmt->fetch(FetchMode::COLUMN);
+
+        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/4007');
+
+        $row = $stmt->fetch(FetchMode::COLUMN);
         self::assertEquals(1, $row);
     }
 
@@ -89,6 +102,8 @@ class LegacyAPITest extends FunctionalTestCase
 
         $stmt = $this->connection->executeQuery($sql);
 
+        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/4007');
+
         $rows = $stmt->fetchAll(FetchMode::ASSOCIATIVE);
         $rows = array_map(static function ($row) {
             return array_change_key_case($row, CASE_LOWER);
@@ -102,6 +117,9 @@ class LegacyAPITest extends FunctionalTestCase
         $sql = 'SELECT test_int FROM legacy_table WHERE test_int = 1';
 
         $stmt = $this->connection->executeQuery($sql);
+
+        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/4007');
+
         $rows = $stmt->fetchAll(FetchMode::NUMERIC);
         self::assertEquals([[0 => 1]], $rows);
     }
@@ -111,6 +129,9 @@ class LegacyAPITest extends FunctionalTestCase
         $sql = 'SELECT test_int FROM legacy_table WHERE test_int = 1';
 
         $stmt = $this->connection->executeQuery($sql);
+
+        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/4007');
+
         $rows = $stmt->fetchAll(FetchMode::COLUMN);
         self::assertEquals([1], $rows);
     }
@@ -148,12 +169,17 @@ class LegacyAPITest extends FunctionalTestCase
         $sql = 'SELECT test_string FROM legacy_table';
 
         $stmt = $this->connection->executeQuery($sql);
+
+        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/4007');
+
         $rows = $stmt->fetchAll(FetchMode::COLUMN);
         self::assertEquals(['foo', 'bar'], $rows);
     }
 
     public function testQuery(): void
     {
+        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/4163');
+
         $stmt = $this->connection->query('SELECT test_string FROM legacy_table WHERE test_int = 1');
 
         $this->assertEquals('foo', $stmt->fetchOne());
@@ -166,6 +192,8 @@ class LegacyAPITest extends FunctionalTestCase
             'test_string' => 'bar',
         ]);
 
+        $this->expectDeprecationWithIdentifier('https://github.com/doctrine/dbal/pull/4163');
+
         $count = $this->connection->exec('DELETE FROM legacy_table WHERE test_int > 1');
 
         $this->assertEquals(1, $count);
