@@ -6,6 +6,7 @@ use DateTime;
 use Doctrine\DBAL\Platforms\AbstractMySQLPlatform;
 use Doctrine\DBAL\Platforms\AbstractPlatform;
 use Doctrine\DBAL\Platforms\MariaDb1027Platform;
+use Doctrine\DBAL\Platforms\MariaDb1043Platform;
 use Doctrine\DBAL\Schema\Schema;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Tests\Functional\Schema\MySQL\PointType;
@@ -13,6 +14,8 @@ use Doctrine\DBAL\Types\BlobType;
 use Doctrine\DBAL\Types\Type;
 use Doctrine\DBAL\Types\Types;
 
+use function array_keys;
+
 class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 {
     public static function setUpBeforeClass(): void
@@ -28,11 +31,11 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
     public function testSwitchPrimaryKeyColumns(): void
     {
         $tableOld = new Table('switch_primary_key_columns');
-        $tableOld->addColumn('foo_id', 'integer');
-        $tableOld->addColumn('bar_id', 'integer');
+        $tableOld->addColumn('foo_id', Types::INTEGER);
+        $tableOld->addColumn('bar_id', Types::INTEGER);
 
         $this->schemaManager->createTable($tableOld);
-        $tableFetched = $this->schemaManager->listTableDetails('switch_primary_key_columns');
+        $tableFetched = $this->schemaManager->introspectTable('switch_primary_key_columns');
         $tableNew     = clone $tableFetched;
         $tableNew->setPrimaryKey(['bar_id', 'foo_id']);
 
@@ -42,7 +45,7 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $this->schemaManager->alterTable($diff);
 
-        $table      = $this->schemaManager->listTableDetails('switch_primary_key_columns');
+        $table      = $this->schemaManager->introspectTable('switch_primary_key_columns');
         $primaryKey = $table->getPrimaryKeyColumns();
 
         self::assertCount(2, $primaryKey);
@@ -54,18 +57,18 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
     {
         $schema = new Schema();
         $table  = $schema->createTable('diffbug_routing_translations');
-        $table->addColumn('id', 'integer');
-        $table->addColumn('route', 'string');
-        $table->addColumn('locale', 'string');
-        $table->addColumn('attribute', 'string');
-        $table->addColumn('localized_value', 'string');
-        $table->addColumn('original_value', 'string');
+        $table->addColumn('id', Types::INTEGER);
+        $table->addColumn('route', Types::STRING);
+        $table->addColumn('locale', Types::STRING);
+        $table->addColumn('attribute', Types::STRING);
+        $table->addColumn('localized_value', Types::STRING);
+        $table->addColumn('original_value', Types::STRING);
         $table->setPrimaryKey(['id']);
         $table->addUniqueIndex(['route', 'locale', 'attribute']);
         $table->addIndex(['localized_value']); // this is much more selective than the unique index
 
         $this->schemaManager->createTable($table);
-        $tableFetched = $this->schemaManager->listTableDetails('diffbug_routing_translations');
+        $tableFetched = $this->schemaManager->introspectTable('diffbug_routing_translations');
 
         $diff = $this->schemaManager->createComparator()
             ->diffTable($tableFetched, $table);
@@ -76,7 +79,7 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
     public function testFulltextIndex(): void
     {
         $table = new Table('fulltext_index');
-        $table->addColumn('text', 'text');
+        $table->addColumn('text', Types::TEXT);
         $table->addIndex(['text'], 'f_index');
         $table->addOption('engine', 'MyISAM');
 
@@ -114,7 +117,7 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
     public function testIndexWithLength(): void
     {
         $table = new Table('index_length');
-        $table->addColumn('text', 'string', ['length' => 255]);
+        $table->addColumn('text', Types::STRING, ['length' => 255]);
         $table->addIndex(['text'], 'text_index', [], ['lengths' => [128]]);
 
         $this->dropAndCreateTable($table);
@@ -127,8 +130,8 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
     public function testAlterTableAddPrimaryKey(): void
     {
         $table = new Table('alter_table_add_pk');
-        $table->addColumn('id', 'integer');
-        $table->addColumn('foo', 'integer');
+        $table->addColumn('id', Types::INTEGER);
+        $table->addColumn('foo', Types::INTEGER);
         $table->addIndex(['id'], 'idx_id');
 
         $this->schemaManager->createTable($table);
@@ -144,7 +147,7 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $this->schemaManager->alterTable($diff);
 
-        $table = $this->schemaManager->listTableDetails('alter_table_add_pk');
+        $table = $this->schemaManager->introspectTable('alter_table_add_pk');
 
         self::assertFalse($table->hasIndex('idx_id'));
         self::assertTrue($table->hasPrimaryKey());
@@ -153,8 +156,8 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
     public function testDropPrimaryKeyWithAutoincrementColumn(): void
     {
         $table = new Table('drop_primary_key');
-        $table->addColumn('id', 'integer', ['autoincrement' => true]);
-        $table->addColumn('foo', 'integer');
+        $table->addColumn('id', Types::INTEGER, ['autoincrement' => true]);
+        $table->addColumn('foo', Types::INTEGER);
         $table->setPrimaryKey(['id', 'foo']);
 
         $this->dropAndCreateTable($table);
@@ -169,7 +172,7 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $this->schemaManager->alterTable($diff);
 
-        $table = $this->schemaManager->listTableDetails('drop_primary_key');
+        $table = $this->schemaManager->introspectTable('drop_primary_key');
 
         self::assertFalse($table->hasPrimaryKey());
         self::assertFalse($table->getColumn('id')->getAutoincrement());
@@ -179,19 +182,19 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
     {
         if ($this->connection->getDatabasePlatform() instanceof MariaDb1027Platform) {
             self::markTestSkipped(
-                'MariaDb102Platform supports default values for BLOB and TEXT columns and will propagate values'
+                'MariaDb102Platform supports default values for BLOB and TEXT columns and will propagate values',
             );
         }
 
         $table = new Table('text_blob_default_value');
-        $table->addColumn('def_text', 'text', ['default' => 'def']);
-        $table->addColumn('def_text_null', 'text', ['notnull' => false, 'default' => 'def']);
-        $table->addColumn('def_blob', 'blob', ['default' => 'def']);
-        $table->addColumn('def_blob_null', 'blob', ['notnull' => false, 'default' => 'def']);
+        $table->addColumn('def_text', Types::TEXT, ['default' => 'def']);
+        $table->addColumn('def_text_null', Types::TEXT, ['notnull' => false, 'default' => 'def']);
+        $table->addColumn('def_blob', Types::BLOB, ['default' => 'def']);
+        $table->addColumn('def_blob_null', Types::BLOB, ['notnull' => false, 'default' => 'def']);
 
         $this->dropAndCreateTable($table);
 
-        $onlineTable = $this->schemaManager->listTableDetails('text_blob_default_value');
+        $onlineTable = $this->schemaManager->introspectTable('text_blob_default_value');
 
         self::assertNull($onlineTable->getColumn('def_text')->getDefault());
         self::assertNull($onlineTable->getColumn('def_text_null')->getDefault());
@@ -208,9 +211,9 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
     public function testColumnCharset(): void
     {
         $table = new Table('test_column_charset');
-        $table->addColumn('id', 'integer');
-        $table->addColumn('foo', 'text')->setPlatformOption('charset', 'ascii');
-        $table->addColumn('bar', 'text')->setPlatformOption('charset', 'latin1');
+        $table->addColumn('id', Types::INTEGER);
+        $table->addColumn('foo', Types::TEXT)->setPlatformOption('charset', 'ascii');
+        $table->addColumn('bar', Types::TEXT)->setPlatformOption('charset', 'latin1');
         $this->dropAndCreateTable($table);
 
         $columns = $this->schemaManager->listTableColumns('test_column_charset');
@@ -225,7 +228,7 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $tableName = 'test_alter_column_charset';
 
         $table = new Table($tableName);
-        $table->addColumn('col_text', 'text')->setPlatformOption('charset', 'utf8');
+        $table->addColumn('col_text', Types::TEXT)->setPlatformOption('charset', 'utf8');
 
         $this->dropAndCreateTable($table);
 
@@ -238,7 +241,7 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $this->schemaManager->alterTable($diff);
 
-        $table = $this->schemaManager->listTableDetails($tableName);
+        $table = $this->schemaManager->introspectTable($tableName);
 
         self::assertEquals('ascii', $table->getColumn('col_text')->getPlatformOption('charset'));
     }
@@ -246,7 +249,7 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
     public function testColumnCharsetChange(): void
     {
         $table = new Table('test_column_charset_change');
-        $table->addColumn('col_string', 'string')
+        $table->addColumn('col_string', Types::STRING)
             ->setLength(100)
             ->setNotnull(true)
             ->setPlatformOption('charset', 'utf8');
@@ -261,7 +264,7 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         self::assertContains(
             'ALTER TABLE test_column_charset_change CHANGE col_string'
                 . ' col_string VARCHAR(100) CHARACTER SET ascii NOT NULL',
-            $diff
+            $diff,
         );
     }
 
@@ -270,11 +273,11 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $table = new Table('test_collation');
         $table->addOption('collation', 'latin1_swedish_ci');
         $table->addOption('charset', 'latin1');
-        $table->addColumn('id', 'integer');
-        $table->addColumn('text', 'text');
-        $table->addColumn('foo', 'text')->setPlatformOption('collation', 'latin1_swedish_ci');
-        $table->addColumn('bar', 'text')->setPlatformOption('collation', 'utf8mb4_general_ci');
-        $table->addColumn('baz', 'text')->setPlatformOption('collation', 'binary');
+        $table->addColumn('id', Types::INTEGER);
+        $table->addColumn('text', Types::TEXT);
+        $table->addColumn('foo', Types::TEXT)->setPlatformOption('collation', 'latin1_swedish_ci');
+        $table->addColumn('bar', Types::TEXT)->setPlatformOption('collation', 'utf8mb4_general_ci');
+        $table->addColumn('baz', Types::TEXT)->setPlatformOption('collation', 'binary');
         $this->dropAndCreateTable($table);
 
         $columns = $this->schemaManager->listTableColumns('test_collation');
@@ -291,15 +294,15 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $tableName = 'lob_type_columns';
         $table     = new Table($tableName);
 
-        $table->addColumn('col_tinytext', 'text', ['length' => AbstractMySQLPlatform::LENGTH_LIMIT_TINYTEXT]);
-        $table->addColumn('col_text', 'text', ['length' => AbstractMySQLPlatform::LENGTH_LIMIT_TEXT]);
-        $table->addColumn('col_mediumtext', 'text', ['length' => AbstractMySQLPlatform::LENGTH_LIMIT_MEDIUMTEXT]);
-        $table->addColumn('col_longtext', 'text');
+        $table->addColumn('col_tinytext', Types::TEXT, ['length' => AbstractMySQLPlatform::LENGTH_LIMIT_TINYTEXT]);
+        $table->addColumn('col_text', Types::TEXT, ['length' => AbstractMySQLPlatform::LENGTH_LIMIT_TEXT]);
+        $table->addColumn('col_mediumtext', Types::TEXT, ['length' => AbstractMySQLPlatform::LENGTH_LIMIT_MEDIUMTEXT]);
+        $table->addColumn('col_longtext', Types::TEXT);
 
-        $table->addColumn('col_tinyblob', 'text', ['length' => AbstractMySQLPlatform::LENGTH_LIMIT_TINYBLOB]);
-        $table->addColumn('col_blob', 'blob', ['length' => AbstractMySQLPlatform::LENGTH_LIMIT_BLOB]);
-        $table->addColumn('col_mediumblob', 'blob', ['length' => AbstractMySQLPlatform::LENGTH_LIMIT_MEDIUMBLOB]);
-        $table->addColumn('col_longblob', 'blob');
+        $table->addColumn('col_tinyblob', Types::TEXT, ['length' => AbstractMySQLPlatform::LENGTH_LIMIT_TINYBLOB]);
+        $table->addColumn('col_blob', Types::BLOB, ['length' => AbstractMySQLPlatform::LENGTH_LIMIT_BLOB]);
+        $table->addColumn('col_mediumblob', Types::BLOB, ['length' => AbstractMySQLPlatform::LENGTH_LIMIT_MEDIUMBLOB]);
+        $table->addColumn('col_longblob', Types::BLOB);
 
         $this->dropAndCreateTable($table);
 
@@ -309,51 +312,51 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         self::assertSame(
             $platform->getClobTypeDeclarationSQL($offlineColumns['col_tinytext']->toArray()),
-            $platform->getClobTypeDeclarationSQL($onlineColumns['col_tinytext']->toArray())
+            $platform->getClobTypeDeclarationSQL($onlineColumns['col_tinytext']->toArray()),
         );
         self::assertSame(
             $platform->getClobTypeDeclarationSQL($offlineColumns['col_text']->toArray()),
-            $platform->getClobTypeDeclarationSQL($onlineColumns['col_text']->toArray())
+            $platform->getClobTypeDeclarationSQL($onlineColumns['col_text']->toArray()),
         );
         self::assertSame(
             $platform->getClobTypeDeclarationSQL($offlineColumns['col_mediumtext']->toArray()),
-            $platform->getClobTypeDeclarationSQL($onlineColumns['col_mediumtext']->toArray())
+            $platform->getClobTypeDeclarationSQL($onlineColumns['col_mediumtext']->toArray()),
         );
         self::assertSame(
             $platform->getClobTypeDeclarationSQL($offlineColumns['col_longtext']->toArray()),
-            $platform->getClobTypeDeclarationSQL($onlineColumns['col_longtext']->toArray())
+            $platform->getClobTypeDeclarationSQL($onlineColumns['col_longtext']->toArray()),
         );
 
         self::assertSame(
             $platform->getBlobTypeDeclarationSQL($offlineColumns['col_tinyblob']->toArray()),
-            $platform->getBlobTypeDeclarationSQL($onlineColumns['col_tinyblob']->toArray())
+            $platform->getBlobTypeDeclarationSQL($onlineColumns['col_tinyblob']->toArray()),
         );
         self::assertSame(
             $platform->getBlobTypeDeclarationSQL($offlineColumns['col_blob']->toArray()),
-            $platform->getBlobTypeDeclarationSQL($onlineColumns['col_blob']->toArray())
+            $platform->getBlobTypeDeclarationSQL($onlineColumns['col_blob']->toArray()),
         );
         self::assertSame(
             $platform->getBlobTypeDeclarationSQL($offlineColumns['col_mediumblob']->toArray()),
-            $platform->getBlobTypeDeclarationSQL($onlineColumns['col_mediumblob']->toArray())
+            $platform->getBlobTypeDeclarationSQL($onlineColumns['col_mediumblob']->toArray()),
         );
         self::assertSame(
             $platform->getBlobTypeDeclarationSQL($offlineColumns['col_longblob']->toArray()),
-            $platform->getBlobTypeDeclarationSQL($onlineColumns['col_longblob']->toArray())
+            $platform->getBlobTypeDeclarationSQL($onlineColumns['col_longblob']->toArray()),
         );
     }
 
     public function testDiffListGuidTableColumn(): void
     {
         $offlineTable = new Table('list_guid_table_column');
-        $offlineTable->addColumn('col_guid', 'guid');
+        $offlineTable->addColumn('col_guid', Types::GUID);
 
         $this->dropAndCreateTable($offlineTable);
 
-        $onlineTable = $this->schemaManager->listTableDetails('list_guid_table_column');
+        $onlineTable = $this->schemaManager->introspectTable('list_guid_table_column');
 
         self::assertFalse(
             $this->schemaManager->createComparator()->diffTable($onlineTable, $offlineTable),
-            'No differences should be detected with the offline vs online schema.'
+            'No differences should be detected with the offline vs online schema.',
         );
     }
 
@@ -362,8 +365,8 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $tableName = 'test_list_decimal_columns';
         $table     = new Table($tableName);
 
-        $table->addColumn('col', 'decimal');
-        $table->addColumn('col_unsigned', 'decimal', ['unsigned' => true]);
+        $table->addColumn('col', Types::DECIMAL);
+        $table->addColumn('col_unsigned', Types::DECIMAL, ['unsigned' => true]);
 
         $this->dropAndCreateTable($table);
 
@@ -380,8 +383,8 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $tableName = 'test_list_float_columns';
         $table     = new Table($tableName);
 
-        $table->addColumn('col', 'float');
-        $table->addColumn('col_unsigned', 'float', ['unsigned' => true]);
+        $table->addColumn('col', Types::FLOAT);
+        $table->addColumn('col_unsigned', Types::FLOAT, ['unsigned' => true]);
 
         $this->dropAndCreateTable($table);
 
@@ -396,9 +399,14 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
     public function testJsonColumnType(): void
     {
         $table = new Table('test_mysql_json');
-        $table->addColumn('col_json', 'json');
+        $table->addColumn('col_json', Types::JSON);
         $this->dropAndCreateTable($table);
 
+        // Remove the comment from the column to ensure the type is detected correctly from the check constraints.
+        if ($this->connection->getDatabasePlatform() instanceof MariaDb1043Platform) {
+            $this->connection->executeStatement('ALTER TABLE test_mysql_json CHANGE COLUMN col_json col_json JSON');
+        }
+
         $columns = $this->schemaManager->listTableColumns('test_mysql_json');
 
         self::assertSame(Types::JSON, $columns['col_json']->getType()->getName());
@@ -412,12 +420,16 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
 
         $currentTimeStampSql = $platform->getCurrentTimestampSQL();
 
-        $table->addColumn('col_datetime', 'datetime', ['notnull' => true, 'default' => $currentTimeStampSql]);
-        $table->addColumn('col_datetime_nullable', 'datetime', ['default' => $currentTimeStampSql]);
+        $table->addColumn(
+            'col_datetime',
+            Types::DATETIME_MUTABLE,
+            ['notnull' => true, 'default' => $currentTimeStampSql],
+        );
+        $table->addColumn('col_datetime_nullable', Types::DATETIME_MUTABLE, ['default' => $currentTimeStampSql]);
 
         $this->dropAndCreateTable($table);
 
-        $onlineTable = $this->schemaManager->listTableDetails('test_column_defaults_current_timestamp');
+        $onlineTable = $this->schemaManager->introspectTable('test_column_defaults_current_timestamp');
         self::assertSame($currentTimeStampSql, $onlineTable->getColumn('col_datetime')->getDefault());
         self::assertSame($currentTimeStampSql, $onlineTable->getColumn('col_datetime_nullable')->getDefault());
 
@@ -430,22 +442,22 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $table = new Table('test_column_defaults_are_valid');
 
         $currentTimeStampSql = $this->connection->getDatabasePlatform()->getCurrentTimestampSQL();
-        $table->addColumn('col_datetime', 'datetime', ['default' => $currentTimeStampSql]);
-        $table->addColumn('col_datetime_null', 'datetime', ['notnull' => false, 'default' => null]);
-        $table->addColumn('col_int', 'integer', ['default' => 1]);
-        $table->addColumn('col_neg_int', 'integer', ['default' => -1]);
-        $table->addColumn('col_string', 'string', ['default' => 'A']);
-        $table->addColumn('col_decimal', 'decimal', ['scale' => 3, 'precision' => 6, 'default' => -2.3]);
-        $table->addColumn('col_date', 'date', ['default' => '2012-12-12']);
+        $table->addColumn('col_datetime', Types::DATETIME_MUTABLE, ['default' => $currentTimeStampSql]);
+        $table->addColumn('col_datetime_null', Types::DATETIME_MUTABLE, ['notnull' => false, 'default' => null]);
+        $table->addColumn('col_int', Types::INTEGER, ['default' => 1]);
+        $table->addColumn('col_neg_int', Types::INTEGER, ['default' => -1]);
+        $table->addColumn('col_string', Types::STRING, ['default' => 'A']);
+        $table->addColumn('col_decimal', Types::DECIMAL, ['scale' => 3, 'precision' => 6, 'default' => -2.3]);
+        $table->addColumn('col_date', Types::DATE_MUTABLE, ['default' => '2012-12-12']);
 
         $this->dropAndCreateTable($table);
 
         $this->connection->executeStatement(
-            'INSERT INTO test_column_defaults_are_valid () VALUES()'
+            'INSERT INTO test_column_defaults_are_valid () VALUES()',
         );
 
         $row = $this->connection->fetchAssociative(
-            'SELECT *, DATEDIFF(CURRENT_TIMESTAMP(), col_datetime) as diff_seconds FROM test_column_defaults_are_valid'
+            'SELECT *, DATEDIFF(CURRENT_TIMESTAMP(), col_datetime) as diff_seconds FROM test_column_defaults_are_valid',
         );
         self::assertNotFalse($row);
 
@@ -483,13 +495,13 @@ class MySQLSchemaManagerTest extends SchemaManagerFunctionalTestCase
         $currentTimeSql      = $platform->getCurrentTimeSQL();
         $currentDateSql      = $platform->getCurrentDateSQL();
 
-        $table->addColumn('col_datetime', 'datetime', ['default' => $currentTimestampSql]);
-        $table->addColumn('col_date', 'date', ['default' => $currentDateSql]);
-        $table->addColumn('col_time', 'time', ['default' => $currentTimeSql]);
+        $table->addColumn('col_datetime', Types::DATETIME_MUTABLE, ['default' => $currentTimestampSql]);
+        $table->addColumn('col_date', Types::DATE_MUTABLE, ['default' => $currentDateSql]);
+        $table->addColumn('col_time', Types::TIME_MUTABLE, ['default' => $currentTimeSql]);
 
         $this->dropAndCreateTable($table);
 
-        $onlineTable = $this->schemaManager->listTableDetails('test_column_defaults_current_time_and_date');
+        $onlineTable = $this->schemaManager->introspectTable('test_column_defaults_current_time_and_date');
 
         self::assertSame($currentTimestampSql, $onlineTable->getColumn('col_datetime')->getDefault());
         self::assertSame($currentDateSql, $onlineTable->getColumn('col_date')->getDefault());
@@ -516,7 +528,7 @@ PARTITION BY HASH (col1)
 SQL;
 
         $this->connection->executeStatement($sql);
-        $onlineTable = $this->schemaManager->listTableDetails('test_table_metadata');
+        $onlineTable = $this->schemaManager->introspectTable('test_table_metadata');
 
         self::assertEquals('InnoDB', $onlineTable->getOption('engine'));
         self::assertEquals('utf8mb4_general_ci', $onlineTable->getOption('collation'));
@@ -533,7 +545,7 @@ SQL;
         $this->connection->executeStatement('DROP TABLE IF EXISTS test_table_empty_metadata');
 
         $this->connection->executeStatement('CREATE TABLE test_table_empty_metadata(col1 INT NOT NULL)');
-        $onlineTable = $this->schemaManager->listTableDetails('test_table_empty_metadata');
+        $onlineTable = $this->schemaManager->introspectTable('test_table_empty_metadata');
 
         self::assertNotEmpty($onlineTable->getOption('engine'));
         // collation could be set to default or not set, information_schema indicate a possibly null value
@@ -542,10 +554,22 @@ SQL;
         self::assertEquals([], $onlineTable->getOption('create_options'));
     }
 
-    public function testParseNullCreateOptions(): void
+    public function testColumnIntrospection(): void
     {
-        $table = $this->schemaManager->listTableDetails('sys.processlist');
+        $table = new Table('test_column_introspection');
 
-        self::assertEquals([], $table->getOption('create_options'));
+        $doctrineTypes = array_keys(Type::getTypesMap());
+
+        foreach ($doctrineTypes as $type) {
+            $table->addColumn('col_' . $type, $type);
+        }
+
+        $this->dropAndCreateTable($table);
+
+        $onlineTable = $this->schemaManager->introspectTable('test_column_introspection');
+
+        $diff = $this->schemaManager->createComparator()->diffTable($table, $onlineTable);
+
+        self::assertFalse($diff, 'Tables should be identical.');
     }
 }
