@@ -8,6 +8,7 @@ use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
 use Doctrine\DBAL\Tests\TestUtil;
 use Doctrine\DBAL\Types\Type;
+use Doctrine\DBAL\Types\Types;
 
 use function base64_decode;
 use function stream_get_contents;
@@ -21,8 +22,8 @@ class StatementTest extends FunctionalTestCase
     protected function setUp(): void
     {
         $table = new Table('stmt_test');
-        $table->addColumn('id', 'integer');
-        $table->addColumn('name', 'text', ['notnull' => false]);
+        $table->addColumn('id', Types::INTEGER);
+        $table->addColumn('name', Types::TEXT, ['notnull' => false]);
         $this->dropAndCreateTable($table);
     }
 
@@ -56,8 +57,8 @@ class StatementTest extends FunctionalTestCase
         }
 
         $table = new Table('stmt_longer_results');
-        $table->addColumn('param', 'string');
-        $table->addColumn('val', 'text');
+        $table->addColumn('param', Types::STRING);
+        $table->addColumn('val', Types::TEXT);
         $this->dropAndCreateTable($table);
 
         $row1 = [
@@ -98,7 +99,7 @@ class StatementTest extends FunctionalTestCase
         $this->iniSet('memory_limit', '4G');
 
         $table = new Table('stmt_long_blob');
-        $table->addColumn('contents', 'blob', ['length' => 0xFFFFFFFF]);
+        $table->addColumn('contents', Types::BLOB, ['length' => 0xFFFFFFFF]);
         $this->dropAndCreateTable($table);
 
         $contents = base64_decode(<<<'EOF'
@@ -123,7 +124,7 @@ EOF
         $result = $this->connection->prepare('SELECT contents FROM stmt_long_blob')
             ->execute();
 
-        $stream = Type::getType('blob')
+        $stream = Type::getType(Types::BLOB)
             ->convertToPHPValue(
                 $result->fetchOne(),
                 $this->connection->getDatabasePlatform(),
@@ -241,7 +242,7 @@ EOF
 
     public function testBindInvalidNamedParameter(): void
     {
-        if (TestUtil::isDriverOneOf('ibm_db2', 'mysqli', 'sqlsrv')) {
+        if (TestUtil::isDriverOneOf('ibm_db2', 'mysqli', 'pgsql', 'sqlsrv')) {
             self::markTestSkipped('The driver does not support named statement parameters');
         }
 
