@@ -7,6 +7,7 @@ use Doctrine\DBAL\Platforms\OraclePlatform;
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
 use Doctrine\DBAL\Types\Type;
+use Doctrine\DBAL\Types\Types;
 use Throwable;
 
 class TemporaryTableTest extends FunctionalTestCase
@@ -19,7 +20,7 @@ class TemporaryTableTest extends FunctionalTestCase
             self::markTestSkipped('Test does not work on Oracle.');
         }
 
-        $columnDefinitions = ['id' => ['type' => Type::getType('integer'), 'notnull' => true]];
+        $columnDefinitions = ['id' => ['type' => Type::getType(Types::INTEGER), 'notnull' => true]];
         $tempTable         = $platform->getTemporaryTableName('my_temporary');
 
         $createTempTableSQL = $platform->getCreateTemporaryTableSnippetSQL() . ' ' . $tempTable . ' ('
@@ -27,7 +28,7 @@ class TemporaryTableTest extends FunctionalTestCase
         $this->connection->executeStatement($createTempTableSQL);
 
         $table = new Table('nontemporary');
-        $table->addColumn('id', 'integer');
+        $table->addColumn('id', Types::INTEGER);
         $table->setPrimaryKey(['id']);
 
         $this->dropAndCreateTable($table);
@@ -51,14 +52,14 @@ class TemporaryTableTest extends FunctionalTestCase
             self::markTestSkipped('Test does not work on Oracle.');
         }
 
-        $columnDefinitions = ['id' => ['type' => Type::getType('integer'), 'notnull' => true]];
+        $columnDefinitions = ['id' => ['type' => Type::getType(Types::INTEGER), 'notnull' => true]];
         $tempTable         = $platform->getTemporaryTableName('my_temporary');
 
         $createTempTableSQL = $platform->getCreateTemporaryTableSnippetSQL() . ' ' . $tempTable . ' ('
                 . $platform->getColumnDeclarationListSQL($columnDefinitions) . ')';
 
         $table = new Table('nontemporary');
-        $table->addColumn('id', 'integer');
+        $table->addColumn('id', Types::INTEGER);
         $table->setPrimaryKey(['id']);
 
         $this->dropAndCreateTable($table);
