@@ -4,14 +4,15 @@ namespace Doctrine\DBAL\Tests\Functional\Ticket;
 
 use Doctrine\DBAL\Schema\Table;
 use Doctrine\DBAL\Tests\FunctionalTestCase;
+use Doctrine\DBAL\Types\Types;
 
 class DBAL168Test extends FunctionalTestCase
 {
     public function testDomainsTable(): void
     {
         $table = new Table('domains');
-        $table->addColumn('id', 'integer');
-        $table->addColumn('parent_id', 'integer');
+        $table->addColumn('id', Types::INTEGER);
+        $table->addColumn('parent_id', Types::INTEGER);
         $table->setPrimaryKey(['id']);
         $table->addForeignKeyConstraint('domains', ['parent_id'], ['id']);
 
