@@ -5,9 +5,9 @@ namespace Doctrine\DBAL\Tests\Platforms\MySQL;
 use Doctrine\DBAL\Platforms\MySQL\CollationMetadataProvider;
 use Doctrine\DBAL\Platforms\MySQL\Comparator;
 use Doctrine\DBAL\Platforms\MySQLPlatform;
-use Doctrine\DBAL\Tests\Schema\ComparatorTest as BaseComparatorTest;
+use Doctrine\DBAL\Tests\Schema\AbstractComparatorTestCase;
 
-class ComparatorTest extends BaseComparatorTest
+class ComparatorTest extends AbstractComparatorTestCase
 {
     protected function setUp(): void
     {
@@ -18,7 +18,7 @@ class ComparatorTest extends BaseComparatorTest
                 {
                     return null;
                 }
-            }
+            },
         );
     }
 }
