@@ -5,6 +5,7 @@ namespace Doctrine\DBAL\Tests\Platforms;
 use Doctrine\DBAL\Platforms\Keywords\MySQLKeywords;
 use Doctrine\DBAL\Platforms\Keywords\ReservedKeywordsValidator;
 use Doctrine\DBAL\Schema\Table;
+use Doctrine\DBAL\Types\Types;
 use PHPUnit\Framework\TestCase;
 
 class ReservedKeywordsValidatorTest extends TestCase
@@ -23,20 +24,20 @@ class ReservedKeywordsValidatorTest extends TestCase
 
         self::assertEquals(
             ['Table TABLE keyword violations: MySQL'],
-            $this->validator->getViolations()
+            $this->validator->getViolations(),
         );
     }
 
     public function testReservedColumnName(): void
     {
         $table  = new Table('TABLE');
-        $column = $table->addColumn('table', 'string');
+        $column = $table->addColumn('table', Types::STRING);
 
         $this->validator->acceptColumn($table, $column);
 
         self::assertEquals(
             ['Table TABLE column table keyword violations: MySQL'],
-            $this->validator->getViolations()
+            $this->validator->getViolations(),
         );
     }
 }
