@@ -4,9 +4,9 @@ namespace Doctrine\DBAL\Tests\Platforms\SQLServer;
 
 use Doctrine\DBAL\Platforms\SQLServer\Comparator;
 use Doctrine\DBAL\Platforms\SQLServer2012Platform;
-use Doctrine\DBAL\Tests\Schema\ComparatorTest as BaseComparatorTest;
+use Doctrine\DBAL\Tests\Schema\AbstractComparatorTestCase;
 
-class ComparatorTest extends BaseComparatorTest
+class ComparatorTest extends AbstractComparatorTestCase
 {
     protected function setUp(): void
     {
