@@ -4,9 +4,9 @@ namespace Doctrine\DBAL\Tests\Platforms\SQLite;
 
 use Doctrine\DBAL\Platforms\SQLite\Comparator;
 use Doctrine\DBAL\Platforms\SqlitePlatform;
-use Doctrine\DBAL\Tests\Schema\ComparatorTest as BaseComparatorTest;
+use Doctrine\DBAL\Tests\Schema\AbstractComparatorTestCase;
 
-class ComparatorTest extends BaseComparatorTest
+class ComparatorTest extends AbstractComparatorTestCase
 {
     protected function setUp(): void
     {
