@@ -18,7 +18,7 @@ class ConnectionTest extends TestCase
             ->method('getServerVersion')
             ->willReturn('1.2.3');
 
-        $connection = new Connection($driverConnection, new Converter(false, false, 0));
+        $connection = new Connection($driverConnection, new Converter(false, false, Converter::CASE_LOWER));
 
         self::assertSame('1.2.3', $connection->getServerVersion());
     }
@@ -27,7 +27,7 @@ class ConnectionTest extends TestCase
     {
         $connection = new Connection(
             $this->createMock(DriverConnection::class),
-            new Converter(false, false, 0),
+            new Converter(false, false, Converter::CASE_LOWER),
         );
 
         $this->expectException(LogicException::class);
@@ -43,7 +43,7 @@ class ConnectionTest extends TestCase
         $driverConnection->method('getNativeConnection')
             ->willReturn($nativeConnection);
 
-        $connection = new Connection($driverConnection, new Converter(false, false, 0));
+        $connection = new Connection($driverConnection, new Converter(false, false, Converter::CASE_LOWER));
 
         self::assertSame($nativeConnection, $connection->getNativeConnection());
     }
@@ -52,7 +52,7 @@ class ConnectionTest extends TestCase
     {
         $connection = new Connection(
             $this->createMock(DriverConnection::class),
-            new Converter(false, false, 0),
+            new Converter(false, false, Converter::CASE_LOWER),
         );
 
         $this->expectException(LogicException::class);
