@@ -5,8 +5,6 @@ namespace Doctrine\DBAL\Tests\Portability;
 use Doctrine\DBAL\Portability\Converter;
 use PHPUnit\Framework\TestCase;
 
-use const CASE_LOWER;
-
 class ConverterTest extends TestCase
 {
     /**
@@ -61,8 +59,9 @@ class ConverterTest extends TestCase
     }
 
     /**
-     * @param array<string,mixed>|false $row
-     * @param array<string,mixed>|false $expected
+     * @param array<string,mixed>|false                        $row
+     * @param Converter::CASE_LOWER|Converter::CASE_UPPER|null $case
+     * @param array<string,mixed>|false                        $expected
      *
      * @dataProvider convertAssociativeProvider
      */
@@ -136,7 +135,7 @@ class ConverterTest extends TestCase
             $row,
             false,
             false,
-            CASE_LOWER,
+            Converter::CASE_LOWER,
             [
                 'foo' => '',
                 'bar' => 'X ',
@@ -147,7 +146,7 @@ class ConverterTest extends TestCase
             $row,
             false,
             true,
-            CASE_LOWER,
+            Converter::CASE_LOWER,
             [
                 'foo' => '',
                 'bar' => 'X',
@@ -158,7 +157,7 @@ class ConverterTest extends TestCase
             $row,
             true,
             false,
-            CASE_LOWER,
+            Converter::CASE_LOWER,
             [
                 'foo' => null,
                 'bar' => 'X ',
@@ -169,7 +168,7 @@ class ConverterTest extends TestCase
             $row,
             true,
             true,
-            CASE_LOWER,
+            Converter::CASE_LOWER,
             [
                 'foo' => null,
                 'bar' => 'X',
@@ -276,8 +275,9 @@ class ConverterTest extends TestCase
     }
 
     /**
-     * @param list<array<string,mixed>> $row
-     * @param list<array<string,mixed>> $expected
+     * @param list<array<string,mixed>>                        $row
+     * @param Converter::CASE_LOWER|Converter::CASE_UPPER|null $case
+     * @param list<array<string,mixed>>                        $expected
      *
      * @dataProvider convertAllAssociativeProvider
      */
@@ -381,7 +381,7 @@ class ConverterTest extends TestCase
             $data,
             false,
             false,
-            CASE_LOWER,
+            Converter::CASE_LOWER,
             [
                 [
                     'foo' => 'X ',
@@ -398,7 +398,7 @@ class ConverterTest extends TestCase
             $data,
             false,
             true,
-            CASE_LOWER,
+            Converter::CASE_LOWER,
             [
                 [
                     'foo' => 'X',
@@ -415,7 +415,7 @@ class ConverterTest extends TestCase
             $data,
             true,
             false,
-            CASE_LOWER,
+            Converter::CASE_LOWER,
             [
                 [
                     'foo' => 'X ',
@@ -432,7 +432,7 @@ class ConverterTest extends TestCase
             $data,
             true,
             true,
-            CASE_LOWER,
+            Converter::CASE_LOWER,
             [
                 [
                     'foo' => 'X',
@@ -499,6 +499,7 @@ class ConverterTest extends TestCase
         ];
     }
 
+    /** @param Converter::CASE_LOWER|Converter::CASE_UPPER|null $case */
     private function createConverter(bool $convertEmptyStringToNull, bool $rightTrimString, ?int $case): Converter
     {
         return new Converter($convertEmptyStringToNull, $rightTrimString, $case);
