@@ -10,10 +10,9 @@ use PHPUnit\Framework\TestCase;
 class SmallIntTest extends TestCase
 {
     /** @var AbstractPlatform&MockObject */
-    private $platform;
+    private AbstractPlatform $platform;
 
-    /** @var SmallIntType */
-    private $type;
+    private SmallIntType $type;
 
     protected function setUp(): void
     {
